#include "dmd.h"
#include <QMessageBox>
#include <qdebug.h>

#define CLEAR_MASK_FILE			"./allblack.bmp"//":/IPOFML/Resources/black.bmp"//"./mask/allblack.bmp"
	
DMD::DMD(QString id, QWidget *parent) : QObject(parent)
{
#ifdef USE_WLP_DMD
#ifdef USE_WLP_ADAPTER
	if(m_wlpAdapter.OpenDev() == false)
	{
		QMessageBox::warning(parent, QString("WLP_ADAPTER"), QString("OpenDev FAIL"));
	}
#else
	bool bFWBeDown = false;
	int ret = WlpDevAlloc(0, &m_wlpDevice, bFWBeDown); 
	if(ret != WLP_SUCCESS) QMessageBox::warning(parent, QString("WLP_DMD"), QString("WlpDevAlloc FAIL"));

	if(bFWBeDown == false)
	{
		PULONGLONG deviceAddr = NULL ;
		deviceAddr = (PULONGLONG)m_wlpDevice ;

		if(WlpDownloadFirmWare(deviceAddr, 0) == false) QMessageBox::warning(parent, QString("WLP_DMD"), QString("WlpDownloadFirmWare FAIL"));

		if(DevReAlloc(deviceAddr) == false) QMessageBox::warning(parent, QString("WLP_DMD"), QString("DevReAlloc FAIL"));
	}

	ULONG dmdtype = 0;
	ret = WlpDevInquire(m_wlpDevice, WLP_DEV_DMD_TYPE, &dmdtype);
	if(ret != WLP_SUCCESS) QMessageBox::warning(parent, QString("WLP_DMD"), QString("WLP_DEV_DMD_TYPE FAIL"));

	ULONG param = 0;
	ret = WlpDevControl(m_wlpDevice, WLP_DEV_RESET, &param);
	if(ret != WLP_SUCCESS) QMessageBox::warning(parent, QString("WLP_DMD"), QString("WLP_DEV_RESET FAIL"));

	Sleep(100);

	ret = WlpDevControl(m_wlpDevice, WLP_DEV_DMD_RESET, &param);
	if(ret != WLP_SUCCESS) QMessageBox::warning(parent, QString("WLP_DMD"), QString("WLP_DEV_DMD_RESET FAIL"));

	Sleep(100);

	m_nGray = 1;
	ret = WlpDevControl(m_wlpDevice, WLP_DEV_GRAY, &m_nGray);
	if(ret != WLP_SUCCESS) QMessageBox::warning(parent, QString("WLP_DMD"), QString("WLP_DEV_GRAY FAIL"));

	ULONG frame_margin = 5000;
	ret = WlpDevControl(m_wlpDevice, WLP_DEV_FRAME_MARGIN, &frame_margin);
	if(ret != WLP_SUCCESS) QMessageBox::warning(parent, QString("WLP_DMD"), QString("WLP_DEV_FRAME_MARGIN FAIL"));
	
	ULONG frame_interval = 0;
	ret = WlpDevControl(m_wlpDevice, WLP_DEV_FRAME_INTERVAL, &frame_interval);
	if(ret != WLP_SUCCESS) QMessageBox::warning(parent, QString("WLP_DMD"), QString("WLP_DEV_FRAME_INTERVAL FAIL"));

	ULONG trigger_setting = (INT) ((INT)1 | WLP_TRIGGER_SINGLE_FRAME | WLP_SYNC_ALL_FRAMES);
	ret = WlpDevControl(m_wlpDevice, WLP_DEV_TRIGGER_SETTING, &trigger_setting);
	if(ret != WLP_SUCCESS) QMessageBox::warning(parent, QString("WLP_DMD"), QString("WLP_DEV_TRIGGER_SETTING FAIL"));

	LONG bitFrameSize = Length_720P * Widthth_720P / 8;
	m_nSingleFrameLen = bitFrameSize * m_nGray;
#endif
#else
	m_pDMD = new QAxWidget(parent);
	m_pDMD->setControl(id);
    m_pDMD->dynamicCall("setBAllowMessages(bool)", QVariant(false));
	m_pDMD->dynamicCall("GetDevice()");
    m_pDMD->dynamicCall("EnableParallel(int)", QVariant(0));

	m_nClearMask = loadToMemBuffer(QString::fromUtf8(CLEAR_MASK_FILE));
#endif
}

DMD::~DMD()
{
#ifdef USE_WLP_DMD
#ifndef USE_WLP_ADAPTER
	WlpDevFree(m_wlpDevice);
#endif
#else
	m_pDMD->dynamicCall("DeleteMemBuf()"); 
#endif
}

#ifdef USE_WLP_DMD
int DMD::loadFiles(QStringList fileNames, bool ns_flip, bool we_flip)
{
	if(fileNames.isEmpty()) return -1;

#ifdef USE_WLP_ADAPTER
	std::vector<string> paramFileNames;
	QImage image;
	QString filename;
	for(int i=0; i<fileNames.count(); i++)
	{
		filename = fileNames.at(i);

		if(ns_flip || we_flip)
		{
			image = QImage(filename).mirrored(we_flip, ns_flip);
			int index = filename.lastIndexOf('.');
			filename.insert(index, QString("_mirrored"));
			image.save(filename);
		}
		
		paramFileNames.push_back(filename.toLatin1().data());
		paramFileNames.push_back(QString(CLEAR_MASK_FILE).toLatin1().data());
	}

	m_wlpAdapter.FileOpen2(paramFileNames);

	return 0;
	
#else
	UINT32 bufLen = m_nSingleFrameLen * (fileNames.count() * 2 + 1);
	PUCHAR imageBuf = (PUCHAR)malloc(sizeof(UCHAR)*bufLen);
	if(!imageBuf) return -1;

	memset(imageBuf, 0x00, sizeof(UCHAR)*bufLen);

	char *convertRet = 0;
	PUCHAR nextAddr = imageBuf + m_nSingleFrameLen;
	QImage image;
	QString filename;
	for(int i=0; i<fileNames.count(); i++)
	{
		filename = fileNames.at(i);

		if(ns_flip || we_flip)
		{
			image = QImage(filename).mirrored(we_flip, ns_flip);
			int index = filename.lastIndexOf('.');
			filename.insert(index, QString("_mirrored"));
			image.save(filename);
		}
		
		convertRet = GetGrayBinFormat(filename.toLatin1().data(), Length_720P, Widthth_720P, 0x80, (char *)nextAddr);
		if(!convertRet) 
		{
			free(imageBuf);
			return -1;
		}

		nextAddr += m_nSingleFrameLen * 2;
	}
	
	int ret = WlpDevLoadFrame(m_wlpDevice, imageBuf, 0, bufLen);
	
	free(imageBuf);

	ULONG param = 0;
	if(WlpDevControl(m_wlpDevice, WLP_DEV_DISPLAY_START_SET, &param) != WLP_SUCCESS) return -1;

	param = bufLen;
	if(WlpDevControl(m_wlpDevice, WLP_DEV_DISPLAY_LENGTH_SET, &param) != WLP_SUCCESS) return -1;
	
	qDebug() << "loadFiles()\n\r";

	return ret;
#endif
}

int DMD::startDMD()
{
#ifdef USE_WLP_ADAPTER
	if(m_wlpAdapter.InitANDDownload(5000, 0, 1, WLP_TRIGGER_SINGLE_FRAME, WLP_SYNC_ALL_FRAMES))
	{
		if(m_wlpAdapter.TriggerExtSet(0, false, 20, m_wlpAdapter.m_Alldonwloadfilecount) != true)
		{
			return -1;
		}

		m_wlpAdapter.Start( );

		UINT data = 0  ; 
		m_wlpAdapter.GetPWMDutyCycle( &data ) ;
	}
#else
	ULONG param = 1;
	if(WlpDevControl(m_wlpDevice, WLP_DEV_DMD_START, &param) != WLP_SUCCESS) return -1;

	Sleep(100);

	param = 1;
	if(WlpDevControl(m_wlpDevice, WLP_DEV_TRIGGER_SINGLE, &param) != WLP_SUCCESS) return -1;

	qDebug() << "startDMD()\n\r";

#endif

	return 1;
}

int DMD::stopDMD()
{
#ifdef USE_WLP_ADAPTER
	m_wlpAdapter.Stop();
	return 0;
#else
	ULONG param = 0;

	int ret = WlpDevControl(m_wlpDevice, WLP_DEV_DMD_RESET, &param);	
	if(ret != WLP_SUCCESS) QMessageBox::warning(0, QString("WLP_DMD"), QString("WLP_DEV_DMD_RESET FAIL"));

	Sleep(100);

	ret = WlpDevControl(m_wlpDevice, WLP_DEV_GRAY, &m_nGray);
	if(ret != WLP_SUCCESS) QMessageBox::warning(0, QString("WLP_DMD"), QString("WLP_DEV_GRAY FAIL"));

	ULONG frame_margin = 5000;
	ret = WlpDevControl(m_wlpDevice, WLP_DEV_FRAME_MARGIN, &frame_margin);
	if(ret != WLP_SUCCESS) QMessageBox::warning(0, QString("WLP_DMD"), QString("WLP_DEV_FRAME_MARGIN FAIL"));
	
	ULONG frame_interval = 0;
	ret = WlpDevControl(m_wlpDevice, WLP_DEV_FRAME_INTERVAL, &frame_interval);
	if(ret != WLP_SUCCESS) QMessageBox::warning(0, QString("WLP_DMD"), QString("WLP_DEV_FRAME_INTERVAL FAIL"));

	ULONG trigger_setting = (INT) ((INT)1 | WLP_TRIGGER_SINGLE_FRAME | WLP_SYNC_ALL_FRAMES);
	ret = WlpDevControl(m_wlpDevice, WLP_DEV_TRIGGER_SETTING, &trigger_setting);
	if(ret != WLP_SUCCESS) QMessageBox::warning(0, QString("WLP_DMD"), QString("WLP_DEV_TRIGGER_SETTING FAIL"));

	qDebug() << "stopDMD()\n\r";

	return ret;
#endif
}

int DMD::trigger(int msec)
{
#ifdef USE_WLP_ADAPTER
	int ret = m_wlpAdapter.Trigger();
#else
	ULONG param = 1;
	int ret = WlpDevControl(m_wlpDevice, WLP_DEV_TRIGGER_SINGLE, &param);

	qDebug() << "trigger()\n\r";

#endif

	if(msec > 0)
	{
		m_bEmitSignalCleared = true;

#ifdef USE_MM_TIMER
		::timeSetEvent(msec, DEFAULT_MMTIMER_RESOLUTION, (LPTIMECALLBACK)loadTimerCallBack,
					   (DWORD)this, TIME_ONESHOT | TIME_CALLBACK_FUNCTION);
#else
		QTimer::singleShot(msec, this, SLOT(slotLoadTimer()));
#endif
	}
	
	return ret;
}
#else
int DMD::loadToMemBuffer(QString fileName)
{
	QVariantList params;
	int bufNum = allocMemBuf();

	params << fileName;
	params << bufNum;
	params << 0;

	m_pDMD->dynamicCall("LoadImageFileToMemBuf(QString, int, int)", params);

	return bufNum;
}

void DMD::unloadFromMemBuffer(int bufNum)
{
	deallocMemBuf(bufNum);
}

int DMD::loadToDMD(int memBuf, int msec)
{
	int ret = 0;

	m_pDMD->dynamicCall("LoadFrameBufferFromMemBuf(int)", QVariant(memBuf));
	ret = m_pDMD->dynamicCall("LoadResetFrame()").toInt();

	if(msec > 0)
	{
		m_bEmitSignalCleared = true;

#ifdef USE_MM_TIMER
		::timeSetEvent(msec, DEFAULT_MMTIMER_RESOLUTION, (LPTIMECALLBACK)loadTimerCallBack,
					   (DWORD)this, TIME_ONESHOT | TIME_CALLBACK_FUNCTION);
#else
		QTimer::singleShot(msec, this, SLOT(slotLoadTimer()));
#endif
	}
	
	return ret;
}


int DMD::allocMemBuf()
{
	int bufNum;

	if(m_nListAllocMemBuf.isEmpty() == true)
	{
		bufNum = m_pDMD->dynamicCall("CreateMemBuf()").toInt();
	}
	else
	{
		bufNum = m_nListAllocMemBuf.takeFirst();
	}

	return bufNum;
}

void DMD::deallocMemBuf(int bufNum)
{
	m_nListAllocMemBuf.append(bufNum);
}
#endif

void DMD::clear()
{
	m_bEmitSignalCleared = false;

#ifdef USE_WLP_DMD
	stopDMD();
#else
	loadToDMD(m_nClearMask);
#endif
}

int DMD::clearDMD()
{
	int ret;

#ifdef USE_WLP_DMD
#ifdef USE_WLP_ADAPTER
	ret = m_wlpAdapter.Trigger();
#else
	ULONG param = 1;
	ret = WlpDevControl(m_wlpDevice, WLP_DEV_TRIGGER_SINGLE, &param);

	qDebug() << "clearDMD()\n\r";

#endif
#else
	ret = loadToDMD(m_nClearMask);
#endif

	if(m_bEmitSignalCleared) emit signalDMDCleared();
	
	return ret;
}

#ifdef USE_MM_TIMER
void DMD::loadTimerCallBack(UINT uID,			//uTimerID
									UINT uMsg,			//dwUser : UserParam
									DWORD dwUser,		//Reserved
									DWORD dw1,			//Reserved
									DWORD dw2)			//Reserved 
{
	DMD *dmd = (DMD *)dwUser;
	dmd->clearDMD();
}
#else
void DMD::slotLoadTimer()
{
	clearDMD();
}
#endif
