#ifndef IPOFML_H
#define IPOFML_H

#include <QtWidgets/QMainWindow>
#include "ui_ipofml.h"
#include "lc8.h"
#include <QLabel>
#include <QComboBox>
#include <QLineEdit>
#include <QPushButton>
#include <QImage>
#include <QSlider>
#include <QCheckBox>
#include <QListWidget>
#include <QUdpSocket>
#include <QTableWidget>
#include "tango.h"
#include "dmd.h"


// for Action 1
#define ACT1_NUM_ROW				1
#define ACT1_NUM_COLUMN				1
#define ACT1_STEP_X					1.5
#define ACT1_STEP_Y					1.5

// for Action 3
#define ACT3_WAITING_FRAME_TIME		300



#define PREVIEW_MASK_WIDTH			290
#define PREVIEW_MASK_HEIGHT			218

#define MAX_COMPORT_NUM				8
#define LC8_COMPORT_NAME			"COM3"
#define STAGE_COMPORT_NAME			"COM1"
#define STAGE_COMPORT_BAUDRATE		57600
#define STAGE_WAIT_FLAG				true


#define DEFAULT_SHUTTER_TIME		0.5
#define DEFAULT_STEP_X				ACT1_STEP_X
#define DEFAULT_STEP_Y				ACT1_STEP_Y
#define DEFAULT_NUM_ROW				ACT1_NUM_ROW
#define DEFAULT_NUM_COLUMN			ACT1_NUM_COLUMN
#define DEFAULT_INTERMOVING_TIME	1


class IPOFML : public QMainWindow
{
	Q_OBJECT

	enum
	{
		ACTION_NONE = 0,
		ACTION_1,		// List
		ACTION_2,		// Preview
		ACTION_3,		// IP-ML
	};

public:
	IPOFML(QWidget *parent = 0, Qt::WindowFlags flags = 0);
	~IPOFML();

private slots:
	void slotUVIntensity(int percent);
	void slotSetUVComPort();
	void slotUVShutterClosed();

	void slotSetStageComPort();

	void slotAct1Clicked();
	void slotAct2Clicked();
	void slotAct3Clicked();

	void slotOnAct2Timer();

	void slotIPMLMaskBtnClicked();
	void slotAddListBtnClicked();
	void slotDeleteListBtnClicked();
	void slotClearListBtnClicked();
	void slotUpListBtnClicked();
	void slotDownListBtnClicked();
	void slotListCurrentRowChanged(int currentRow, int currentColumn, int previousRow, int previousColumn);

	void slotDMDCleared();
	void slotOnInterMovingTimerByDMD();

	void slotActionStopBtnClicked();

private:
	Ui::IPOFMLClass ui;

	LC8 *m_pLC8;
	LC8Control *m_pLC8Ctrl;

	DMD *m_pDDC1100;
	CTango *m_pTango;

	QPushButton *m_pAct1, *m_pAct2, *m_pAct3;
	int m_nActType;
	int m_nCurRow, m_nCurColumn;
	
	QComboBox *m_pUVPort;
	QLineEdit *m_pShutterTime;

	QComboBox *m_pStagePort;
	QLineEdit *m_pDistanceX;
	QLineEdit *m_pDistanceY;
	QLineEdit *m_pNumColumn;
	QLineEdit *m_pNumRow;
	QLineEdit *m_pInterMovingTime;
	
	void initUVSource();
	void initStage();
	void initDMD();
	void setTabWidget();

	QPushButton *intensityUpBtn, *intensityDownBtn;

	QLabel *m_pIPMLPreviewMask;
	QLineEdit *m_pIPMLMask;
	QPushButton *m_pIPMLMaskBtn;
	int m_nIPMLDMDMemBuf;

	QTableWidget *m_pMaskTableWidget;
	QPushButton *m_pAddListBtn, *m_pDeleteListBtn, *m_pClearListBtn;
	QPushButton *m_pUpListBtn, *m_pDownListBtn;
	QLabel *m_pListPreviewMask;
	int listIndex;
	QCheckBox *m_pListOnOneSpotCBox;

	void actionUIEnabled(bool enable);

	QPushButton *m_pActionStopBtn;

#ifdef USE_WLP_DMD
	QCheckBox *m_pMaskNSFlip, *m_pMaskWEFlip;
#endif
};

#endif // IPOFML_H
