#include "lc8.h"

LC8::LC8(QWidget *parent)
	: QFrame(parent)
{
	ui.setupUi(this);
}

LC8::~LC8()
{

}

void LC8::setShutterTime(double sec)
{
	ui.lcdNumber_2->display(sec);
}

void LC8::setIntensity(int percent)
{
	ui.lcdNumber->display(percent);
}

void LC8::setShutterTime(const QString &sec)
{
	ui.lcdNumber_2->display(sec);
}

void LC8::setIntensity(const QString &percent)
{
	ui.lcdNumber->display(percent);
}


/*=================================================*/
/* LC8Control Class                                */
/*=================================================*/
LC8Control::LC8Control(QObject *parent)
{
	m_pSerialPort = new QextSerialPort();
	m_pSerialPort->setBaudRate(BAUD9600);
	m_pSerialPort->setDataBits(DATA_8);
	m_pSerialPort->setParity(PAR_NONE);
	m_pSerialPort->setStopBits(STOP_1);
	m_pSerialPort->setQueryMode(QextSerialPort::EventDriven);

	m_strRecv = "";
	m_bWaitClose = false;

	QObject::connect(m_pSerialPort, SIGNAL(readyRead()), this, SLOT(slotReadSerialPort()));
}

LC8Control::~LC8Control()
{
	if(m_pSerialPort->isOpen()) m_pSerialPort->close();
	
	delete m_pSerialPort;
}

void LC8Control::connect(const QString &portName)
{
	m_pSerialPort->setPortName(portName);
	
	if(m_pSerialPort->open(QIODevice::ReadWrite) == true)
	{
		commandControl();
	}
}

void LC8Control::disconnect()
{
	if(m_pSerialPort->isOpen())
	{
		frontPanelControl();
		m_pSerialPort->close();	
	}
}

void LC8Control::frontPanelControl()
{
	m_pSerialPort->write("CNT0\r", 5);
}

void LC8Control::commandControl()
{
	int ret = m_pSerialPort->write("CNT1\r", 5);
	ret++;
}

void LC8Control::lampOn()
{
	m_pSerialPort->write("L1\r", 3);
}

void LC8Control::lampOff()
{
	m_pSerialPort->write("L0\r", 3);
}

void LC8Control::shutterOpen(int msec)
{
	m_pSerialPort->write("S1\r", 3);

	if(msec > 0)
	{
#ifdef USE_MM_TIMER
		::timeSetEvent(msec, DEFAULT_MMTIMER_RESOLUTION, (LPTIMECALLBACK)shutterOpenCallBack,
					   (DWORD)this, TIME_ONESHOT | TIME_CALLBACK_FUNCTION);
#else
		QTimer::singleShot(msec, this, SLOT(slotShutterTimer()));
#endif
	}
}

void LC8Control::shutterClose()
{
	m_pSerialPort->write("S0\r", 3);
}

void LC8Control::intensityUp()
{
	m_pSerialPort->write("INT1\r", 5);
}

void LC8Control::intensityDown()
{
	m_pSerialPort->write("INT2\r", 5);
}

void LC8Control::intensityStop()
{
	m_pSerialPort->write("INT0\r", 5);
}

void LC8Control::queryIntensity()
{
	m_pSerialPort->write("INTQ\r", 5);
}

void LC8Control::slotReadSerialPort()
{
	int bytes = m_pSerialPort->bytesAvailable();
	if(bytes > 0)
	{
		char data;

		for(int i=0; i<bytes; i++)
		{
			m_pSerialPort->read(&data, 1);
			if(data == '\r')
			{
				parse();
				m_strRecv.clear();
			}
			else
			{
				m_strRecv.append(data);
			}
		}
	}
}

void LC8Control::parse()
{
	if(m_strRecv.startsWith("CNT"))
	{
		m_strRecv.remove(0, 3);

		if(m_strRecv.compare("1OK") == 0)
		{
			emit signalConnected();
		}
		else if(m_strRecv.compare("0OK") == 0)
		{
			emit signalDisconnected();
		}
	}
	else if(m_strRecv.startsWith("L"))
	{
		m_strRecv.remove(0, 1);

		if(m_strRecv.compare("1OK") == 0)
		{
			emit signalLampOn();
		}
		else if(m_strRecv.compare("0OK") == 0)
		{
			emit signalLampOff();
		}
	}
	else if(m_strRecv.startsWith("S"))
	{
		m_strRecv.remove(0, 1);

		if(m_strRecv.compare("1OK") == 0)
		{
			emit signalShutterOpen();
		}
		else if(m_strRecv.compare("0OK") == 0)
		{
			//emit signalShutterClose();
			m_bWaitClose = true;
		}
	}
	else if(m_strRecv.startsWith("INT"))
	{
		m_strRecv.remove(0, 3);

		if(m_strRecv.compare("1OK")==0 || m_strRecv.compare("2OK")==0)
		{

		}
		else if(m_strRecv.compare("0OK") == 0)
		{
			queryIntensity();
		}
		else
		{
			bool ok;
			int percent = m_strRecv.toInt(&ok, 10);
			
			emit signalIntensity(percent);
		}
	}	
	else if(m_strRecv.startsWith("INP0"))
	{
		m_strRecv.remove(0, 4);

		bool ok;
		int percent = m_strRecv.toInt(&ok, 10);

		if(m_bWaitClose==true && (percent&0x04)==0) 
		{
			m_bWaitClose = false;
			emit signalShutterClose();
		}
	}
}

#ifdef USE_MM_TIMER
void LC8Control::shutterOpenCallBack(UINT uID,			//uTimerID
									UINT uMsg,			//dwUser : UserParam
									DWORD dwUser,		//Reserved
									DWORD dw1,			//Reserved
									DWORD dw2)			//Reserved 
{
	LC8Control *lc8Ctrl = (LC8Control *)dwUser;
	lc8Ctrl->shutterClose();
}
#else
void LC8Control::slotShutterTimer()
{
	shutterClose();
}
#endif