#ifndef LC8_H
#define LC8_H

#include <QFrame>
#include "ui_lc8.h"
#include "qextserialport.h"
#include <QString>

#ifdef USE_MM_TIMER
	#include "mmtimer.h"
#else
	#include <QTimer>
#endif

class LC8Control;

class LC8 : public QFrame
{
	Q_OBJECT

public:
	LC8(QWidget *parent = 0);
	~LC8();

public slots:
	void setShutterTime(double sec);
	void setShutterTime(const QString &sec);
	void setIntensity(int percent);
	void setIntensity(const QString &percent);

private:
	Ui::LC8Class ui;
};


class LC8Control : public QObject
{
	Q_OBJECT

	typedef enum
	{
		ConnectionError = 0,
		UnknownError
	}LC8ControlError;

public:
	LC8Control(QObject *parent=0);
	~LC8Control();

	void connect(const QString &portName);
	void disconnect();

#ifdef USE_MM_TIMER
	static void CALLBACK shutterOpenCallBack( UINT uID,			//uTimerID
									UINT uMsg,			//dwUser : UserParam
									DWORD dwUser,		//Reserved
									DWORD dw1,			//Reserved
									DWORD dw2);			//Reserved 
#endif
	
public slots:
	void frontPanelControl();
	void commandControl();
	void lampOn();
	void lampOff();
	void shutterOpen(int msec=0);
	void shutterClose();
	void intensityUp();
	void intensityDown();
	void intensityStop();
	void queryIntensity();

signals:
	void signalConnected();
	void signalDisconnected();
	void signalShutterTime(double sec);
	void signalIntensity(int percent);
	void signalLampOn();
	void signalLampOff();
	void signalLampStable();
	void signalShutterOpen();
	void signalShutterClose();
	void signalError(LC8Control::LC8ControlError error);

private slots:
	void slotReadSerialPort();
#ifndef USE_MM_TIMER
	void slotShutterTimer();
#endif

private:
	QextSerialPort *m_pSerialPort;
	QString m_strRecv;
	bool m_bWaitClose;

	void parse();
};

#endif // LC8_H
