#include "mtimer.h"
#include "mmsystem.h"
#include <QMetaMethod>

class MTimerInternal
{
public:
	MTimerInternal(QObject *object, int methodIndex)
	{
		m_pObject = object;
		m_nMethodIndex = methodIndex;
	}
	~MTimerInternal(){}

	QObject* object() const {return m_pObject;}
	int methodIndex() const {return m_nMethodIndex;}

private:
	QObject *m_pObject;
	int m_nMethodIndex;
};


MTimer::MTimer(QObject *parent) : QObject(parent)
{
	m_nInterval = 0;
	m_bActive = false;
	m_bSingleShot = true;
	m_nTimerID = -1;

	m_zeroIntervalTimer.setInterval(0);

	connect(this, SIGNAL(timeout()), this, SLOT(slotTimeout()));
	connect(&m_zeroIntervalTimer, SIGNAL(timeout()), this, SIGNAL(timeout()));
}

MTimer::~MTimer()
{
	if(m_bActive) stop();
}

int MTimer::interval() const
{
	return m_nInterval;
}

bool MTimer::isActive() const
{
	return m_bActive;
}

bool MTimer::isSingleShot() const
{
	return m_bSingleShot;
}

void MTimer::setInterval(int msec)
{
	if(msec >= 0) m_nInterval = msec;
}

void MTimer::setSingleShot(bool singleShot)
{
	m_bSingleShot = singleShot;
}

int MTimer::timerId() const
{
	return m_nTimerID;
}	

void MTimer::singleShot(int msec, QObject *receiver, const char *member)
{
	if(msec > 0)
	{
		int i, size = strlen(member);
		for(i=0; i<size; i++)
		{
			if(member[i]<'0' || member[i]>'9') break;
		}	

		int mIndex = receiver->metaObject()->indexOfMethod(member+i);
		MTimerInternal *recv = new MTimerInternal(receiver, mIndex);
		::timeSetEvent(msec, DEFAULT_MMTIMER_RESOLUTION, (LPTIMECALLBACK)mmtimerOneShotCallBack, (DWORD)recv, TIME_ONESHOT | TIME_CALLBACK_FUNCTION | TIME_KILL_SYNCHRONOUS);
	}
	else if(msec == 0)
	{
		QTimer::singleShot(msec, receiver, member);
	}
}

void MTimer::start(int msec)
{
	if(m_bActive) stop();

	if(msec > 0)
	{
		m_nInterval = msec;

		if(m_bSingleShot)
		{
			m_nTimerID = ::timeSetEvent(m_nInterval, DEFAULT_MMTIMER_RESOLUTION, (LPTIMECALLBACK)mmtimerCallBack, (DWORD)this, TIME_ONESHOT | TIME_CALLBACK_FUNCTION | TIME_KILL_SYNCHRONOUS);
		}
		else
		{
			m_nTimerID = ::timeSetEvent(m_nInterval, DEFAULT_MMTIMER_RESOLUTION, (LPTIMECALLBACK)mmtimerCallBack, (DWORD)this, TIME_PERIODIC | TIME_CALLBACK_FUNCTION | TIME_KILL_SYNCHRONOUS);
		}

		m_bActive = true;
	}
	else if(msec == 0)
	{
		m_nInterval = msec;

		m_zeroIntervalTimer.setSingleShot(m_bSingleShot);
		m_zeroIntervalTimer.start(m_nInterval);

		m_nTimerID = m_zeroIntervalTimer.timerId();

		m_bActive = m_zeroIntervalTimer.isActive();
	}
}

void MTimer::start()
{
	start(m_nInterval);
}

void MTimer::stop()
{
	if(m_bActive)
	{
		if(m_zeroIntervalTimer.isActive()) m_zeroIntervalTimer.stop();
		else timeKillEvent(m_nTimerID);

		m_bActive = false;
		m_nTimerID = -1;
	}	
}

void MTimer::mmtimerCallBack(UINT uID, UINT uMsg, DWORD dwUser, DWORD dw1, DWORD dw2)
{
	MTimer *timer = (MTimer *)dwUser;
	emit timer->timeout();
}

void MTimer::mmtimerOneShotCallBack(UINT uID, UINT uMsg, DWORD dwUser, DWORD dw1, DWORD dw2)
{
	MTimerInternal *mtimerIInternal = (MTimerInternal *)dwUser;
	
	QObject *object = mtimerIInternal->object();
	const QMetaObject *metaObject = object->metaObject();
	
	int mIndex = mtimerIInternal->methodIndex();	
	
	QMetaMethod method = metaObject->method(mIndex);
	method.invoke(object, Qt::DirectConnection);
	
	delete mtimerIInternal;
}

void MTimer::slotTimeout()
{
	if(m_bSingleShot)
	{
		m_bActive = false;
		m_nTimerID = -1;
	}
}
