#include "valvearray.h"


Valve::Valve(int nPort, int nChannel)
{
    m_bIsChecked = false;
    m_nPort = nPort;
    m_nChannel = nChannel;

    setStyleSheet("background-color:white");
    setFrameShape(QFrame::Box);
}

bool Valve::isChecked()
{
    return m_bIsChecked;
}

void Valve::mousePressEvent(QMouseEvent *event)
{
    if(event->button() == Qt::LeftButton)
    {
        if(m_bIsChecked)
        {
            m_bIsChecked = false;
            setStyleSheet("background-color:white");
        }
        else
        {
            m_bIsChecked = true;
            setStyleSheet("background-color:orange");
        }

        emit signalCheckChanged(m_nPort, m_nChannel, m_bIsChecked);
    }
}

void Valve::setCheck(bool check)
{
    if(m_bIsChecked == check) return;

    m_bIsChecked = check;

    if(m_bIsChecked) setStyleSheet("background-color:orange");
    else setStyleSheet("background-color:white");
}

ValveArray::ValveArray(int nPort, int nChannel)
{
    m_nPort = nPort;
    m_nChannel = nChannel;

    int i, j;
    Valve *valve;
    QSpacerItem *spacer;

    m_hlayoutValve = new QHBoxLayout;

    for(i=0; i<nPort; i++)
    {
        for(j=0; j<nChannel; j++)
        {
            valve = new Valve(i, j);

            m_listValve.append(valve);
            m_hlayoutValve->addWidget(valve);

            connect(valve, SIGNAL(signalCheckChanged(int,int,bool)), this, SIGNAL(signalCheckChanged(int,int,bool)));
        }

        if(i != nPort-1)
        {
            spacer = new QSpacerItem(0, 0);
            m_listSpacer.append(spacer);

            m_hlayoutValve->addSpacerItem(spacer);
        }
    }

    setLayout(m_hlayoutValve);
}

ValveArray::~ValveArray()
{
    Valve *valve;

    while(m_listValve.isEmpty() == false)
    {
         valve = m_listValve.takeFirst();
         delete valve;
    }
}

void ValveArray::setValveFixedSize(int width, int height)
{
    int i;
    Valve *valve;

    for(i=0; i<m_listValve.size(); i++)
    {
        valve = m_listValve.at(i);
        valve->setFixedSize(width, height);
    }
}

void ValveArray::setSpacerFixedSize(int width, int height)
{
    int i;
    QSpacerItem *spacer;

    for(i=0; i<m_listSpacer.size(); i++)
    {
        spacer = m_listSpacer.at(i);
        spacer->changeSize(width, height);
    }
}

int ValveArray::numPort()
{
    return m_nPort;
}

int ValveArray::numChannel()
{
    return m_nChannel;
}

bool ValveArray::isChecked(int nPort, int nChannel)
{
    return m_listValve.at(nPort*m_nChannel+nChannel)->isChecked();
}

void ValveArray::setValve(int nPort, int nChannel, bool open)
{
    m_listValve.at(nPort*m_nChannel+nChannel)->setCheck(open);
}
