#include "valvectrl.h"

#define DEVICE_ID	"Dev1"
#define NUM_OF_PORT     4
#define NUM_OF_CHANNEL  8

typedef struct _ValveCtrlParam
{
	ValveCtrl *ctrl;
	int port;
	int channel;
}ValveCtrlParam;

ValveCtrl::ValveCtrl(QObject *parent)
	: QObject(parent)
{
	initNIDAQmx();
    writeNIDAQmx();
}

ValveCtrl::~ValveCtrl()
{

}

void ValveCtrl::initNIDAQmx()
{
    DAQmxCreateTask("", &m_taskOut);

    QString str = QString(QString(DEVICE_ID) + QString("/port0:3"));
    DAQmxCreateDOChan(m_taskOut, str.toAscii().data(), "", DAQmx_Val_ChanForAllLines);
    DAQmxStartTask(m_taskOut);

    m_data = 0;
}

void ValveCtrl::open(int port, int channel, int msec)
{
	m_data |= (1<<(port*NUM_OF_CHANNEL+channel));
	writeNIDAQmx();

	if(msec > 0)
	{
		ValveCtrlParam *param = new ValveCtrlParam;
		param->ctrl = this;
		param->port = port;
		param->channel = channel;

		::timeSetEvent(msec, DEFAULT_MMTIMER_RESOLUTION, (LPTIMECALLBACK)openTimerCallBack, (DWORD)param, TIME_ONESHOT | TIME_CALLBACK_FUNCTION);
	}
}

void ValveCtrl::close(int port, int channel)
{
	m_data &= ~(1<<(port*NUM_OF_CHANNEL+channel));	
	writeNIDAQmx();
}

void ValveCtrl::closeAll()
{
    m_data = 0;
    writeNIDAQmx();
}

void ValveCtrl::writeNIDAQmx()
{
    DAQmxWriteDigitalU32(m_taskOut, 1, 1, 10.0, DAQmx_Val_GroupByChannel, &m_data, NULL, NULL);
}

void ValveCtrl::openTimerCallBack(UINT uID,	UINT uMsg, DWORD dwUser, DWORD dw1, DWORD dw2)
{
	ValveCtrlParam *param = (ValveCtrlParam *)dwUser;
	ValveCtrl *ctrl = param->ctrl;
	
	ctrl->close(param->port, param->channel);
}
