
/** 
*@file wlp_adapter.h
*@brief wlp_adapter.lib main header file
*@author longf@dspchina.com
*/



#ifndef __WLP_ADAPTER_H__
#define __WLP_ADAPTER_H__



#pragma once


#include<vector>
#include<algorithm>
#include<string>
#include <functional>
using namespace std;



#include "wlp_interface.h"
#include "image_convert.h"

#include "I2C_Addr.h"
#include "lis3dh_driver.h"


/** @brief trigger Enable */
#define WLP_TRIGGER_DISABLE			0x00000000		/**< ignore external or software trigger signal.*/
#define WLP_TRIGGER_ENABLE			0x00000001		/**< trigger is enable.*/

/** @brief enmu trigger mode */
#define WLP_TRIGGER_SINGLE_FRAME	0x00000000		/**< one trigger for one frame mode.*/
#define WLP_TRIGGER_FRAMES			0x00000002		/**< one trigger display all frames and then auto stop ,or stop by trigger.*/
#define WLP_TRIGGER_FRAMES_AND_AUTOSTOP	0x00000004	/**< display all frames  and ignore all trigger signal before it's auto stop.*/
#define WLP_TRIGGER_LOOP			0x00000006		/**< loop display all frames, at the end of the stream,first frame will be showed again.*/

#define WLP_TRIGGER_MODE_5          0x00000008 


/** @brief enmu output sync signal mode */
#define WLP_SYNC_ALL_FRAMES			0x00000000		/**< signal out after display all frames.*/
#define WLP_SYNC_SINGLE_FRAME		0x00000008		/**< signal out after display every frame.*/


typedef struct {

	ULONG dmdtype;			/**< device dmdtype, more infomation looking discription on WlpDevControl.*/

/**< image display time. The time unit is  nanosecond.
    * for .7 dmd: The min value of frame_margin is 13.64.
    * for .95 dmd:	The min value of frame_margin is 13.64.
*/
	ULONG frame_margin ;

/**< after image display, the black time.  The time unit is  nanosecond.
    * The min value of frame_interval is 0.
    * The default value is 0.
*/
	ULONG frame_interval ;

	ULONG gray;				/**< device gray, more infomation looking discription on WlpDevControl.*/
	ULONG trigger_setting;  /**< device trigger setting, more infomation looking discription on WlpDevControl.*/

}DEVINIT2 , *PDEVINIT2 ;





/**< IIC operation parameter .
*    
*    
*/   
typedef struct
{
	UCHAR  W_or_R  ;      /**< indicator  */
	ULONG  NumOfBytes;   
	ULONG  DevAddr ;	  /**< IIC slave device address  */
	ULONG  RegAddr ;      /**< Register address in the device  */

	UCHAR  W_Data[4];  /**< to contain the data write to IIC slave device */
	UCHAR  R_Data[4];  /**< to contain the data read from IIC slave device */

} I2C_OPER , *pI2C_OPER ;




typedef struct {

	ULONG TrigeModeX ;
	//bool  IfBeTriggered ;

	ULONG m_FrameMarginForMode1   ;
	ULONG m_FrameIntervalForMode1 ;

}SophistcateTrigger ;



/**
*  @class WLP_Adapter
*
*  @brief define the member functions for the application to operate the WLP board,
*   the upper program can easily use this class to build a demo project .
*
**/


class WLP_Adapter
{

public:

	WLP_Adapter();
	~WLP_Adapter();

public:

	WLP_HDEVICE device ;
	BOOL m_bDevopened;
	DEVINIT2 DevInit ;

	bool OpenDev( void );
	void CloseDev( void );
//	bool  PrepareDMD( ) ;
	void DevRemoved( ) ;

	void FileOpen( char *foldName  );
	void FileOpen2( std::vector<string>& flist  );

	bool InitANDDownload(   UINT m_FrameMargin , 
							UINT m_FrameInterval ,
							UINT gray ,
							int trigeMode , 
							int trigeSync   ) ;


	void Start( ) ;
	void Stop( void );


	LONG SetTrigerMode1(  int trigeMode , int trigeSync );
	LONG SetTrigerMode2(  int trigeMode , int trigeSync );
	ULONG TrigerSetALL( int trigeMode , int trigeSync ); 
	LONG Trigger();

	LONG NsFlip( BOOL bNS_FLIP );
	LONG CompData( BOOL bNS_COMP_DATA );

	LONG SetPWMDutyCycle( UINT PWMDutyCycle ) ;
	LONG GetPWMDutyCycle( PUINT PWMDutyCycle ) ;

	LONG LEDCtrl( UINT LedCtrlData ) ;

	LONG GPIO_Set(  UINT GPIO_SetValue ) ;
	LONG GPIO_Get( PUINT GPIO_GetValue ) ;

	bool I2CPWM_SetDutyCycle( UINT PWMData ) ;
	UCHAR I2CPWM_GetDutyCycle(   ) ;

	void I2CLED_Set( UINT PWMData ) ;
	UCHAR I2CLED_Get(   ) ;

	ULONG Gyroscope_Read( UCHAR RegAddr , UINT numBytes ) ;

	void  NanoAccelTest( );
	ULONG LIS3DH_ReadReg(  UCHAR RegAddr , UCHAR* Data ) ;
	ULONG LIS3DH_WriteReg( UCHAR RegAddr , UCHAR Data  ) ;
	status_t LIS3DH_GetWHO_AM_I(u8_t* val);
	status_t LIS3DH_SetODR(LIS3DH_ODR_t ov );
	status_t LIS3DH_SetMode(LIS3DH_Mode_t md) ;
	status_t LIS3DH_SetFullScale(LIS3DH_Fullscale_t fs) ;
	status_t LIS3DH_SetAxis(LIS3DH_Axis_t axis) ;
	status_t LIS3DH_GetAccAxesRaw(AxesRaw_t* buff) ;


	void LTC2489_SetCH( UCHAR ChannelSet ) ;
	ULONG LTC2489_ReadMode1(  UINT CH_X  );

	ULONG FrameActiveTime  ;

    ULONG  RAMsize  ;  
	bool  Read_DDR_SPD( );
 

	void Wlp_DevRReg(  );
	void Wlp_GetFWversion(  );
	bool Wlp_DevNewFrequencySet( ULONG gray , ULONG frame_margin, ULONG frame_interval );
	void ResetBoard(   ) ;



	bool TriggerExtSet(  ULONG delay , bool polay , ULONG plusewidth , ULONG ImageNum  ) ;

	ULONG  m_Alldonwloadfilecount ;

private:

	LONG m_BitFrameSize;
	vector<string> m_filenames;
	void  get_filelist( char *foldName, std::vector<string>& filelist ) ;
	void  GetFiles(char *foldName, std::vector<string>& flist)  ;

	bool InitDev(  UINT m_FrameMargin , 
					UINT m_FrameInterval ,  
					UINT gray ,
					int trigeMode , int trigeSync  ) ; 

	LONG  WlpDevInit2( WLP_HDEVICE hDevice , PDEVINIT2 pDevInit ) ;


	bool DownloadFile( void ) ;
	ULONG SingleDownload( ULONG ThisTimeStartAddr ,    
		                  ULONG SingleDownSize , 
						  ULONG DownloadTimes ,
						  ULONG ThisTimeConvertFileCount  ,
						  ULONG SingleFrameLen ) ;

	PUCHAR pLargeImageBuff ;
//	ULONG  m_Alldonwloadfilecount ;

	LONG I2CCtrl( I2C_OPER I2CWriteOper ) ;
	LONG I2CWriteData( PULONG WData ) ;
	LONG I2CReadData(  PULONG RData );

	void I2CPWM_W( UINT PWMData ); 
	void I2CPWM_R( PUINT pPWMData );

	void I2C_W( I2C_OPER I2COper ); 
	void I2C_R( I2C_OPER I2COper );

	int FWdownloaded ; 
 
	PUCHAR ReadCompare ;

	SophistcateTrigger ThisTrigger ;
	vector<SophistcateTrigger>  TriggerQueue ;
	bool ReadyforTrigger ; 

	int DMDtype ; 

};



enum ddr3_reg_map {
	/* 0 */
	DDR3_SPD_REG_SIZE_CRC,
	DDR3_SPD_REG_REVISION,
	DDR3_SPD_REG_DEVICE_TYPE,
	DDR3_SPD_REG_MODULE_TYPE,
	DDR3_SPD_REG_DENSITY_BANKS,
	DDR3_SPD_REG_ADDRESSING,
	DDR3_SPD_REG_VOLTAGE,
	DDR3_SPD_REG_MODULE_ORG,
	DDR3_SPD_REG_MODULE_BUS_WIDTH,
	DDR3_SPD_REG_FTB_DIVIDEND_DIVSOR,
	/* 10 */
	DDR3_SPD_REG_MTB_DIVIDEND,
	DDR3_SPD_REG_MTB_DIVISOR,
	DDR3_SPD_REG_TCK_MIN,
	DDR3_SPD_REG_RESERVED,
	DDR3_SPD_REG_CAS_LAT_LSB,
	DDR3_SPD_REG_CAS_LAT_MSB,
	DDR3_SPD_REG_TAA_MIN,
	DDR3_SPD_REG_TWR_MIN,
	DDR3_SPD_REG_TRCD_MIN,
	DDR3_SPD_REG_TRRD_MIN,
	/* 20 */
	DDR3_SPD_REG_TRP_MIN,
	DDR3_SPD_REG_TRAS_TRC_UP_NIBBLE,
	DDR3_SPD_REG_TRAS_MIN_LSB,
	DDR3_SPD_REG_TRC_MIN_LSB,
	DDR3_SPD_REG_TRFC_MIN_LSB,
	DDR3_SPD_REG_TRFC_MIN_MSB,
	DDR3_SPD_REG_TWTR_MIN,
	DDR3_SPD_REG_TRTP_MIN,
	DDR3_SPD_REG_TFAW_UP_NIBBLE,
	DDR3_SPD_REG_TFAW_MIN,
	/* 30 */
	DDR3_SPD_REG_OPT_FEATURES,
	DDR3_SPD_REG_THERM_REFRESH_OPT,
	DDR3_SPD_REG_MODULE_THERM_SENSOR,
	DDR3_SPD_REG_SDRAM_DEVICE_TYPE,
	DDR3_SPD_REG_GENERAL_SECTION_START,
	DDR3_SPD_REG_GENERAL_SECTION_END = 59,
	/* 60 */
	DDR3_SPD_REG_MODULE_SPECIFIC_SECTION_START,
	DDR3_SPD_REG_MODULE_SPECIFIC_SECTION_END = 116,
	/* 117 */
	DDR3_SPD_REG_MODULE_MANUF_JEDEC_ID_LSB,
	DDR3_SPD_REG_MODULE_MANUF_JEDEC_ID_MSB,
	DDR3_SPD_REG_MODULE_MANUF_LOC,
	/* 120 */
	DDR3_SPD_REG_MODULE_MANUF_DATE_YEAR,
	DDR3_SPD_REG_MODULE_MANUF_DATE_WEEK,
	DDR3_SPD_REG_MODULE_MANUF_SERIAL_0,
	DDR3_SPD_REG_MODULE_MANUF_SERIAL_1,
	DDR3_SPD_REG_MODULE_MANUF_SERIAL_2,
	DDR3_SPD_REG_MODULE_MANUF_SERIAL_3,
	DDR3_SPD_REG_CRC_0,
	DDR3_SPD_REG_CRC_1,
	DDR3_SPD_REG_MODULE_PART_NUM_0,
	DDR3_SPD_REG_MODULE_PART_NUM_START = DDR3_SPD_REG_MODULE_PART_NUM_0,
	DDR3_SPD_REG_MODULE_PART_NUM_1,
	/* 130 */
	DDR3_SPD_REG_MODULE_PART_NUM_2,
	DDR3_SPD_REG_MODULE_PART_NUM_3,
	DDR3_SPD_REG_MODULE_PART_NUM_4,
	DDR3_SPD_REG_MODULE_PART_NUM_5,
	DDR3_SPD_REG_MODULE_PART_NUM_6,
	DDR3_SPD_REG_MODULE_PART_NUM_7,
	DDR3_SPD_REG_MODULE_PART_NUM_8,
	DDR3_SPD_REG_MODULE_PART_NUM_9,
	DDR3_SPD_REG_MODULE_PART_NUM_10,
	DDR3_SPD_REG_MODULE_PART_NUM_11,
	/* 140 */
	DDR3_SPD_REG_MODULE_PART_NUM_12,
	DDR3_SPD_REG_MODULE_PART_NUM_13,
	DDR3_SPD_REG_MODULE_PART_NUM_14,
	DDR3_SPD_REG_MODULE_PART_NUM_15,
	DDR3_SPD_REG_MODULE_PART_NUM_16,
	DDR3_SPD_REG_MODULE_PART_NUM_17,
	DDR3_SPD_REG_MODULE_PART_NUM_END = DDR3_SPD_REG_MODULE_PART_NUM_17,
	DDR3_SPD_REG_MODULE_REVISION_0,
	DDR3_SPD_REG_MODULE_REVISION_1,
	DDR3_SPD_REG_DRAM_MANUF_JEDEC_ID_LSB,
	DDR3_SPD_REG_DRAM_MANUF_JEDEC_ID_MSB,
	DDR3_SPD_REG_MANUF_SPECIFIC_DATA_START,
	DDR3_SPD_REG_MANUF_SPECIFIC_DATA_END = 175,
	/* 176 */
	DDR3_SPD_REG_CUSTOMER_USE_START,
	DDR3_SPD_REG_CUSTOMER_USE_END = 255,
};


#endif __WLP_ADAPTER_H__